*Zap it to Me";

*This do file runs the regressions in the Zap it to Me paper
*There are a number of errors in the published version, some of which are covered in an Erratum on the EDCC website and a Corringendum on Jenny Aker's website
*This .do file replicates the results in the November 2016 version online at Jenny Aker's webpage

#delimit;
clear;
set more off;

*******************************************************************************************;
	if c(username)=="jennaker" {
		global dropbox = "/Users/jennaker/Dropbox"	
		}
		
*Set macros*;
global replicate = "$dropbox/Zap/3ie"
**********************************************************************************;

log using "$dl/analysis.log", replace
set more off

use "$replicate/zaphousehold.dta", replace
set more off

*************************************************;
*CREATE COMPOSITE VARIABLES USED IN THE ANALYSIS*;
*************************************************;
sort id time

//There are several composite variables in the dataset.  Those variables were created using the below codes for each round. To recreate the variables in the dataset, the below code would need to be modified to re-create those variables by household and time period.  

/*
egen assets=rsum( tv flashlight petrollamp strawhouse strawmudhouse mudhouse cementhouse generator bike moto cart plow car radio cellphone)
replace assets=. if tv==. & flashlight==. & petrollamp==. & strawhouse==. & mudhouse==. & strawmudhouse==. & cementhouse==. & generator==. & bike==. & moto==. & cart==. & plow==. & car==. & radio==. & cellphone==.
label var assets "Number of asset categories owned by household"

egen assets_nophone=rsum( tv flashlight petrollamp strawhouse strawmudhouse mudhouse cementhouse generator bike moto cart plow car radio)
replace assets_nophone=. if tv==. & flashlight==. & petrollamp==. & strawhouse==. & mudhouse==. & strawmudhouse==. & cementhouse==. & generator==. & bike==. & moto==. & cart==. & plow==. & car==. & radio==.
label var assets_nophone "Number of asset categories owned by household (excluding cell phone)"

bysort id time: egen durable=rsum(plow cart bike moto)
label var durable "Durable good categories owned by household"
replace durable=. if plow==. & cart==. & bike==. & moto==.

egen nondurable=rsum(flashlight petrollamp radio)
label var nondurable "Non-durable good categories owned by household"
replace nondurable=. if flashlight==. & petrollamp==. & radio==.

egen hdds=rsum(tubercule grain beans vegetables fruit meat fish egg dairy fat sugars condiments)
replace hdds=. if grain==. & tubercule==. & beans==. & vegetables==. & fruit==. & meat==. & fish==. & egg==. & dairy==. & fat==. & sugars==. & condiments==.

gen attrit10=0 if time==1
replace attrit10=1 if (findhouse==0|findresp==0) & time==1
replace attrit10=. if findhouse==. & findresp==. & time==1
label var attrit10 "Respondent attrition for December 2010 Data"

gen attrit10_hh=0 if time==1
replace attrit10_hh=1 if caninterview==0 & time==1
replace attrit10_hh=. if caninterview==. & time==1
label var attrit10_hh "Household attrition for December 2010 data"

gen attrit11=0 if time==2
replace attrit11=1 if (findhouse==0|findresp==0) & time==2
label var attrit11 "Respondent attrition for May 2011 Data"
replace attrit11=1 if whynotfind_other=="N'ETANT PAS BENEFICIAIRE DU CASH, ELLE A REFUSE L'ENTRETIEN" & time==2

gen attrit11_hh=0 if time==2
replace attrit11_hh=1 if caninterview==0 & time==2
label var attrit11_hh "Household attrition for May 2011 data"
replace attrit11_hh=1 if whynotfind_other=="N'ETANT PAS BENEFICIAIRE DU CASH, ELLE A REFUSE L'ENTRETIEN" & time==2
*/

****************************************************************;
*TABLE 2. CHECK FOR BALANCEDNESS AMONG PRE-TREATMENT COVARIATES*;
****************************************************************;

set more off
* initialize outreg
		xi: reg hhage ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	      	outreg2 using "$replicate/table2.xls", replace excel
		xi: reg hhage ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
			outreg2 using "$replicate/table2.xls", append excel

*********;
*PANEL A*;
*********;
global demo="hhage polygamy hausa hhmem_no numchild hhed_mean"

foreach i in $demo {
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	test ittmobile=ittplacebo
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")
}

foreach i in $demo{
	tabstat `i' if ittcash==1 & time==0, stat(mean, sd)
	}

//Check to see if results are similar without controlling for the presence of a seed program

set more off
* initialize outreg
		xi: reg hhage ittmobile ittplacebo i.commune if time==0, robust cluster(villagecode)
	      	outreg2 using "$replicate/table2check.xls", replace excel
		xi: reg hhage ittmobile ittcash i.commune if time==0, robust cluster(villagecode)
			outreg2 using "$replicate/table2check.xls", append excel
			
foreach i in $demo {
	xi: reg `i' ittmobile ittplacebo i.commune if time==0, robust cluster(villagecode)
	test ittmobile=ittplacebo
	outreg2 using "$replicate/table2check.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table2check.xls", dec(2) append excel ctitle("`i'")
}
**********;
*PANEL B*;
*********;
set more off

global income="ag livestock remittance assets"

foreach i in $income{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	test ittmobile=ittplacebo
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")
}


foreach i in $income{
	tabstat `i' if ittcash==1 & time==0, stat(mean, sd)
	}

//Check to see if results are similar without controlling for the presence of a seed program

set more off
* initialize outreg
		xi: reg hhage ittmobile ittplacebo i.commune if time==0, robust cluster(villagecode)
	      	outreg2 using "$replicate/table2check.xls", replace excel
		xi: reg hhage ittmobile ittcash i.commune if time==0, robust cluster(villagecode)
			outreg2 using "$replicate/table2check.xls", append excel
			
foreach i in $income {
	xi: reg `i' ittmobile ittplacebo i.commune if time==0, robust cluster(villagecode)
	test ittmobile=ittplacebo
	outreg2 using "$replicate/table2check.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table2check.xls", dec(2) append excel ctitle("`i'")
}
	

*********;
*PANEL C*;
*********;
set more off
global cell="cellphone usecellphone call0 zap0"

summ $cell if time==0

foreach i in $cell{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	test ittmobile=ittplacebo
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")
}


foreach i in $cell{
	tabstat `i' if ittcash==1 & time==0, stat(mean, sd)
	}

//Check if similar when not including seed program

foreach i in $cell {
	xi: reg `i' ittmobile ittplacebo i.commune if time==0, robust cluster(villagecode)
	test ittmobile=ittplacebo
	outreg2 using "$replicate/table2check.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table2check.xls", dec(2) append excel ctitle("`i'")
}
	
*********;
*PANEL D*;
*********;
set more off
global shock="drought0 crickets0"

foreach i in $shock{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	test ittmobile=ittplacebo
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")
}

foreach i in $shock{
	tabstat `i' if ittcash==1 & time==0, stat(mean, sd)
	}

//Check it without the seed variable

foreach i in $shock {
	xi: reg `i' ittmobile ittplacebo i.commune if time==0, robust cluster(villagecode)
	test ittmobile=ittplacebo
	outreg2 using "$replicate/table2check.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table2check.xls", dec(2) append excel ctitle("`i'")
}

*********;
*PANEL E*:
*********;
set more off
global village "market villageschool seed"

//The below should be done on collapsed variables, as this will artificially increase the number of observations and hence the likelihood of detecting a s.s. difference

sort id

/*
//First do it without collapsing -- this is not included in the table, but similar results

foreach i in $village{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	test ittmobile=ittplacebo
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")
}

foreach i in $village{
	tabstat `i' if ittcash==1 & time==0, stat(mean, sd)
	}

//Now do it without the seed variable, as the above isn't appropriate for the seed dependent variable

foreach i in $village{
	xi: reg `i' ittmobile ittplacebo i.commune if time==0, robust cluster(villagecode)
	test ittmobile=ittplacebo
	outreg2 using "$replicate/table2check.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table2check.xls", dec(2) append excel ctitle("`i'")
}

*/

//Now collapse and estimate the same regressions, without clustering the s.e.; this should be what is included in the table
collapse market villageschool seed ittmobile ittplacebo ittcash commune if time==0, by(villagecode)

foreach i in $village{
	tabstat `i' if ittcash==1, stat(mean, sd)
	}

foreach i in $village{
	xi: reg `i' ittmobile ittplacebo seed i.commune, robust
	test ittmobile=ittplacebo
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash seed i.commune, robust
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")
}

//Now check without the seed program (for the seed dependent variable)

	xi: reg seed ittmobile ittplacebo i.commune, robust
	test ittmobile=ittplacebo
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")	
	xi: reg seed ittmobile ittcash i.commune, robust
	outreg2 using "$replicate/table2.xls", dec(2) append excel ctitle("`i'")

	
clear

**********************************************;
*TABLE 3. BALANCE TABLE FOR BASELINE OUTCOMES*;
**********************************************;

use "$replicate/zaphousehold.dta", replace
set more off
tab id

* initialize outreg
		xi: reg hdds ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	      	outreg2 using "$replicate/table3.xls", dec(2) replace excel
		xi: reg hdds ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
			outreg2 using "$replicate/table3.xls", dec(2) append excel

*********;
*PANEL A*;
*********;
set more off
global foodsecurity "mahfp hdds"

foreach i in $foodsecurity{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table3.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table3.xls", dec(2) append excel ctitle("`i'")
}

foreach i in $foodsecurity{
	tabstat `i' if ittcash==1 & time==0, stat(mean, sd)
	}
	
//Do check without seed control

		xi: reg hdds ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	      	outreg2 using "$replicate/table3check.xls", dec(2) replace excel
		xi: reg hdds ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
			outreg2 using "$replicate/table3check.xls", dec(2) append excel
			
foreach i in $foodsecurity{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table3check.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table3check.xls", dec(2) append excel ctitle("`i'")
}


	
*********;
*PANEL B*;
*********;
global migrate="migrate_hh nbrremit0 remitzap0"

summ $migrate if time==0

foreach i in $migrate{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table3.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table3.xls", dec(2) append excel ctitle("`i'")
}

foreach i in $migrate{
	tabstat `i' if ittcash==1 & time==0, stat(mean, sd)
	}

//Check without seed control
foreach i in $migrate{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table3check.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table3check.xls", dec(2) append excel ctitle("`i'")
}
	
*********;
*PANEL C*;
*********;

global ag "cultivate mil milqty0 cowpea cowpeaqty0 vouandzougombo"

summ $ag if time==0


foreach i in $ag{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table3.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table3.xls", dec(2) append excel ctitle("`i'")
}

foreach i in $ag{
	tabstat `i' if ittcash==1 & time==0, stat(mean, sd)
	}

//Check without seed program

foreach i in $ag{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table3check.xls", dec(2) append excel ctitle("`i'")	
	xi: reg `i' ittmobile ittcash seed i.commune if time==0, robust cluster(villagecode)
	outreg2 using "$replicate/table3check.xls", dec(2) append excel ctitle("`i'")
}

********************;
*TABLE A1 ATTRITION*;
********************;

global attrit="attrit10 attrit10_hh attrit11 attrit11_hh"
summ $attrit

//The below are for the 93 baseline villages

set more off

		reg attrit10 ittmobile ittplacebo seed if time==1, robust cluster(villagecode)
	    outreg2 using "$replicate/tablea1.xls", dec(2) replace excel
		reg attrit10 ittmobile ittcash seed if time==1, robust cluster(villagecode)
		outreg2 using "$replicate/tablea1.xls", dec(2) append excel

//This is the preferred specification; all other specifications excluding seeds and adding in the baseline controls are robust
//This will just be a cross-sectional regression, since attrit10 is just for December 2010 and attrit11 is just for May 2011

foreach i in $attrit{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/tablea1.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/tablea1.xls", dec(2) append excel ctitle("`i'")
	}

foreach i in $attrit{
	tabstat `i' if ittcash==1 & time!=0, stat(mean, sd)
	}		

//The below are robustness checks, not included in the table: Without seed fixed effects, control for baseline differences

	reg howusetransfer ittmobile ittplacebo seed if time==1, robust cluster(villagecode)
	outreg2 using "$replicate/tablea1check.xls", dec(2) replace excel
	reg howusetransfer ittmobile ittcash seed if time==1, robust cluster(villagecode)
	outreg2 using "$replicate/tablea1check.xls", dec(2) append excel

//Without seed fixed effects

foreach i in $attrit{
	xi: reg `i' ittmobile ittplacebo i.commune, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/tablea1check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash i.commune, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/tablea1check.xls", dec(2) append excel ctitle("`i'")
	}

//Create baseline covariates for time 1

sort id time
foreach i in hhage livestock cowpea{
	gen `i'_baseline=`i'[_n-1]
	}

	//The below tests whether observable characteristics are driving attrition
//Control for covariates with baseline differences, such as age, livestock and cowpea; this won't run for the 2011 attrition data, as the baseline values are not included in that year, but can be

foreach i in $attrit{
	xi: reg `i' ittmobile ittplacebo seed hhage_baseline livestock_baseline cowpea_baseline i.commune, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/tablea1check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed hhage_baseline livestock_baseline cowpea_baseline i.commune, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/tablea1check.xls", dec(2) append excel ctitle("`i'")
	}
	
********************************;
*TABLE 4. USES OF CASH TRANSFER*;
********************************;

set more off
global howusetransfer "howusetransfer transfer_cereal transfer_othercer transfer_cowpea transfer_condi transfer_oil transfer_meat transfer_school transfer_health transfer_clothes"

//General usage, don't need to specify time==1 because only collected during that time
summ $howusetransfer if time==1

summ $howusetransfer if time==1 & ittcash==1
summ transfer_debt transfer_labor if time==1 & ittcash==1
//Originally a variable called "transfer what" which listed what they bought if it was not on the list; no temptation goods mentioned here.
	
//The same results if include comparison==0, since the control households in treatment villages did not receive the transfer

* initialize outreg
		xi: reg howusetransfer ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	      	outreg2 using "$replicate/table4.xls", dec(2) replace excel
		xi: reg howusetransfer ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
			outreg2 using "$replicate/table4.xls", dec(2) append excel

//This first specific specification is without any controls; all other specifications are robust except cowpeas

foreach i in $howusetransfer{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table4.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table4.xls", dec(2) append excel ctitle("`i'")
	}

foreach i in $howusetransfer{
	tabstat `i' if ittcash==1 & time==1, stat(mean, sd)
	}		

//Robustness checks: Without seed fixed effects, control for baseline differences

	reg howusetransfer ittmobile ittplacebo seed if time==1, robust cluster(villagecode)
	outreg2 using "$replicate/table4check.xls", dec(2) replace excel
	reg howusetransfer ittmobile ittcash seed if time==1, robust cluster(villagecode)
	outreg2 using "$replicate/table4check.xls", dec(2) append excel

//Without seed fixed effects

foreach i in $howusetransfer{
	xi: reg `i' ittmobile ittplacebo i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table4check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table4check.xls", dec(2) append excel ctitle("`i'")
	}

//Control for covariates with baseline differences, such as age, livestock and cowpea
foreach i in $howusetransfer{
	xi: reg `i' ittmobile ittplacebo seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table4check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table4check.xls", dec(2) append excel ctitle("`i'")
	}
	
*************************************;
*TABLE A2: RESULTS FOR LAST TRANSFER*;
*************************************;
set more off

global howuselasttransfer "howuselasttransfer lasttransfer_cereal lasttransfer_othercer lasttransfer_cowpea lasttransfer_oil lasttransfer_condi lasttransfer_meat lasttransfer_school lasttransfer_health lasttransfer_clothes"
summ $howuselasttransfer
summ $howuselasttransfer if time==1

//The exchange rate in September 2010 was about 514 CFA=1 USD
xi: reg howuselasttransfer ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 using "$replicate/tablea2.xls", dec(2) replace excel
xi: reg howuselasttransfer ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 using "$replicate/tablea2.xls", dec(2) append excel
	
foreach i in $howuselasttransfer{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/tablea2.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/tablea2.xls", dec(2) append excel ctitle("`i'")
	}

foreach i in $howuselasttransfer{
	tabstat `i' if ittcash==1 & time==1, stat(mean, sd)
	}

//Robustness checks: Without seed fixed effects, control for baseline differences

	reg howuselasttransfer ittmobile ittplacebo seed if time==1, robust cluster(villagecode)
	outreg2 using "$replicate/tablea2check.xls", dec(2) replace excel
	reg howuselasttransfer ittmobile ittcash seed if time==1, robust cluster(villagecode)
	outreg2 using "$replicate/tablea2check.xls", dec(2) append excel

//Without seed fixed effects

foreach i in $howusetransfer{
	xi: reg `i' ittmobile ittplacebo i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/tablea2check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/tablea2check.xls", dec(2) append excel ctitle("`i'")
	}

//Control for covariates with baseline differences, such as age, livestock and cowpea
foreach i in $howusetransfer{
	xi: reg `i' ittmobile ittplacebo seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/tablea2check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/tablea2check.xls", dec(2) append excel ctitle("`i'")
	}

******************************************************;
*TABLE 5. EFFECTS ON FOOD SECURITY, ASSETS AND COPING*;
*******************************************************;
set more off
* initialize outreg
		xi: reg hdds ittmobile ittplacebo seed time i.commune if time!=0, robust cluster(villagecode)
	    outreg2 ittmobile ittplacebo using "$replicate/table5.xls", dec(2) replace excel
		xi: reg hdds ittmobile ittcash seed time i.commune if time!=0, robust cluster(villagecode)
		outreg2 ittmobile ittplacebo using "$replicate/table5.xls", dec(2) append excel

*********;
*PANEL A*;
*********;
set more off	
global foodsecurity="hdds grain beans fat meat condiments fruit"

summ $foodsecurity if time!=0
summ $foodsecurity if time==1
summ $foodsecurity if time==2

foreach i in $foodsecurity{
	xi: reg `i' ittmobile ittplacebo seed time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table5.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash time seed i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table5.xls", dec(2) append excel ctitle("`i'")
}

foreach i in $foodsecurity{
	tabstat `i' if ittcash==1 & time!=0, stat(mean, sd)
	}
	
//Robustness checks: Without seed fixed effects, control for baseline differences
set more off
	reg hdds ittmobile ittplacebo seed if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table5check.xls", dec(2) replace excel
	reg hdds ittmobile ittcash seed if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table5check.xls", dec(2) append excel

//With comparison group included, same as above
foreach i in $foodsecurity{
	xi: reg `i' ittmobile ittplacebo seed time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table5check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash time seed i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table5check.xls", dec(2) append excel ctitle("`i'")
}

//Without seed fixed effects

foreach i in $foodsecurity{
	xi: reg `i' ittmobile ittplacebo time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table5check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table5check.xls", dec(2) append excel ctitle("`i'")
	}

//Control for covariates with baseline differences, such as age, livestock and cowpea
foreach i in $foodsecurity{
	xi: reg `i' ittmobile ittplacebo seed time hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table5check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed time hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table5check.xls", dec(2) append excel ctitle("`i'")
	}
	
****************;
*PANEL C* ASSETS;
****************;
set more off
global assets "assets assets_nophone durable nondurable"
set more off

//Now check for general cohesion among variables, although less important here

summ $assets if time!=0
summ $assets if time==1
summ $assets if time==2

foreach i in $assets{
	xi: reg `i' ittmobile ittplacebo seed time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table5.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table5.xls", dec(2) append excel ctitle("`i'")
}

foreach i in $assets{
	tabstat `i' if ittcash==1 & time!=0, stat(mean, sd)
	}


//With comparison group included, same as above
foreach i in $assets{
	xi: reg `i' ittmobile ittplacebo seed time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table5check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash time seed i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table5check.xls", dec(2) append excel ctitle("`i'")
}

//Without seed fixed effects

foreach i in $assets{
	xi: reg `i' ittmobile ittplacebo time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table5check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table5check.xls", dec(2) append excel ctitle("`i'")
	}

//Control for covariates with baseline differences, such as age, livestock and cowpea
foreach i in $assets{
	xi: reg `i' ittmobile ittplacebo seed time hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table5check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed time hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table5check.xls", dec(2) append excel ctitle("`i'")
	}

clear

************************************;
*PANEL B: NUTRITIONAL STATUS;
************************************;
use "$replicate/zapchilddiet.dta", replace

//Create child household diet diversity index
/*
sort no
egen hdds_child=rsum(localgrains tubers legumes vita otherlegumes otherfruits meat fish eggs dairy fats sugars condiments plumpy)
replace hdds_child=. if local==. & tubers==. & legumes==. & vita==. & otherleg==.
*/

set more off

global childdiet="nbrmeals hdds_child"

		areg hdds_child ittmobile ittplacebo seed, a(commune) robust cluster(villagecode)
	    outreg2 ittmobile ittplacebo using "$replicate/table5nutrition.xls", dec(2) replace excel
		areg hdds_child ittmobile ittcash seed, a(commune) robust cluster(villagecode)
		outreg2 ittmobile ittplacebo using "$replicate/table5nutrition.xls", dec(2) append excel

foreach i in $childdiet{
	areg `i' ittmobile ittplacebo seed, a(commune) robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table5nutrition.xls", dec(2) append excel ctitle("`i'")
	areg `i' ittmobile ittcash seed, a(commune) robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table5nutrition.xls", dec(2) append excel ctitle("`i'")
	}

foreach i in $childdiet{
	tabstat `i' if ittcash==1, stat(mean, sd)
	}

//Check without commune fixed effects

		reg hdds_child ittmobile ittplacebo seed, robust cluster(villagecode)
	    outreg2 ittmobile ittplacebo using "$replicate/table5nutritioncheck.xls", dec(2) replace excel
		reg hdds_child ittmobile ittcash seed, robust cluster(villagecode)
		outreg2 ittmobile ittplacebo using "$replicate/table5nutritioncheck.xls", dec(2) append excel

foreach i in $childdiet{
	reg `i' ittmobile ittplacebo seed, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table5nutritioncheck.xls", dec(2) append excel ctitle("`i'")
	reg `i' ittmobile ittcash seed, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table5nutritioncheck.xls", dec(2) append excel ctitle("`i'")
	}

clear

use "$replicate/zapanthro.dta", replace

//Those observations greater than 59 months do not have WAZ, HAZ or WHZ calculated

	areg z_WHZ ittmobile ittplacebo seed, a(commune) robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table5nutrition.xls", dec(2) append excel ctitle("`i'")
	areg z_WHZ ittmobile ittcash seed, a(commune) robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table5nutrition.xls", dec(2) append excel ctitle("`i'")

tabstat z_WHZ if ittcash==1, stat(mean, sd)

clear
	
****************************************;
*TABLE A3: ROBUSTNESS CHECKS FOR TABLE 4;
****************************************;

use "$replicate/zaphousehold.dta", replace
set more off

		xi: reg hdds ittmobile ittplacebo seed time i.commune if time!=0, robust cluster(villagecode)
	    outreg2 ittmobile ittplacebo using "$replicate/tablea3.xls", dec(2) replace excel
		xi: reg hdds ittmobile ittcash seed time i.commune if time!=0, robust cluster(villagecode)
		outreg2 ittmobile ittplacebo using "$replicate/tablae3.xls", dec(2) append excel


//First create baseline values of outcome variables

sort id time
foreach i in $foodsecurity $assets{
	by id: gen `i'_baseline=`i' if time==0
	by id: replace `i'_baseline=`i'[_n-1] if time==1
	by id: replace `i'_baseline=`i'_baseline[_n-1] if time==2
	}
	
//ANCOVA

foreach i in $foodsecurity $assets{
	xi: reg `i' ittmobile ittplacebo seed time `i'_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/tablea3.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed time `i'_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/tablea3.xls", dec(2) append excel ctitle("`i'")
	}

*December-only data

foreach i in $foodsecurity $assets{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/tablea3.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/tablea3.xls", dec(2) append excel ctitle("`i'")
	}

foreach i in $foodsecurity $assets{
	tabstat `i' if ittcash==1 & time==1, stat(mean, sd)
	}
	
//May-only data

foreach i in $foodsecurity $assets{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==2, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/tablea3.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time==2, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/tablea3.xls", dec(2) append excel ctitle("`i'")
	}

foreach i in $foodsecurity $assets{
	tabstat `i' if ittcash==1 & time==2, stat(mean, sd)
	}	

****************;
*FIGURE 1 COSTS*;
****************;

//This shows the difference in unconditional means; the second is a regression
//anycash is the cash/mobile group

ttest distance_transfer if time==1, by(anycash)

xi: reg distance_transfer anycash seed i.commune if time==1, robust

//Now generate the Zap group comparison

gen anyzap=(anycash==0)

//Mean of anycash group
tabstat distance_transfer if anycash==1 & time==1, stat(mean, sd)

//Mean of Zap group
tabstat distance_transfer if anycash==0 & time==1, stat(mean, sd)

******************;
*TABLE 6: LEAKAGE*;
******************;
//Recreate baseline covariates for time 1
set more off
sort id time
foreach i in hhage livestock cowpea{
	gen `i'_baseline=`i'[_n-1]
	}

* initialize outreg
		reg receivetransferconcern ittmobile ittplacebo seed if time==1, robust cluster(villagecode)
	      	outreg2 ittmobile ittplacebo using "$replicate/table6.xls", dec(2) replace excel

global leakage="receivetransferconcern nbrtransfers totaltransfer"
set more off

summ $leakage

foreach i in $leakage{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table6.xls", dec(2) append excel
	xi: reg `i' ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table6.xls", dec(2) append excel	
	}

foreach i in $leakage{
	tabstat `i' if ittcash==1 & time==1, stat(mean, sd)
	}

//Robustness checks

//With comparison group included, same as above

set more off
	reg receivetransfer ittmobile ittplacebo seed if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table6check.xls", dec(2) replace excel
	reg receivetransfer ittmobile ittcash seed if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table6check.xls", dec(2) append excel
	
foreach i in $leakage{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table6check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table6check.xls", dec(2) append excel ctitle("`i'")
}

//Without seed fixed effects

foreach i in $leakage{
	xi: reg `i' ittmobile ittplacebo i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table6check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table6check.xls", dec(2) append excel ctitle("`i'")
	}

//Control for covariates with baseline differences, such as age, livestock and cowpea
foreach i in $leakage{
	xi: reg `i' ittmobile ittplacebo seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table6check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table6check.xls", dec(2) append excel ctitle("`i'")
	}
	
**********************;
*TABLE A4. AGRICULTURE ;
**********************;
set more off

global ag "cultivate numproduced mil cowpea vouandzou gombo vouandzougombo cowpeaqty0 vgqty0 numsell milsel0 cowpeasel0 vouandzougombosel0"

//The ag data were only collected in December, immediately after the harvest

summ $ag

//Weird outlier for millet quantity, but keep it

* initialize outreg
		reg cultivate ittmobile ittplacebo if time==1, robust cluster(villagecode)
	      	outreg2 using "$replicate/tablea4.xls", dec(2) replace excel
		reg cultivate ittmobile ittcash if time==1, robust cluster(villagecode)
			outreg2 using "$replicate/tablea4.xls", dec(2) append excel

foreach i in $ag{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/tablea4.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/tablea4.xls", dec(2) append excel ctitle("`i'")
	}

foreach i in $ag{
	tabstat `i' if ittcash==1 & time!=0, stat(mean sd)
	}

//Control for baseline covariates/ANCOVA

sort id time

foreach i in cultivate numproduced mil vouandzougombo milqty0 cowpeaqty0 vgqty0 numsell milsel0 cowpeasel0 vouandzougombosel0{
	by id: gen `i'_baseline=`i' if time==0
	by id: replace `i'_baseline=`i'[_n-1] if time==1
	}

foreach i in $ag{
	xi: reg `i' ittmobile ittplacebo seed hhage_baseline cowpea_baseline livestock_baseline i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/tablea4check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed hhage_baseline cowpea_baseline livestock_baseline i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/tablea4check.xls", dec(2) append excel ctitle("`i'")
	}

foreach i in cultivate numproduced mil vouandzougombo milqty0 cowpeaqty0 vgqty0 numsell milsel0 cowpeasel0 vouandzougombosel0{
	xi: reg `i' ittmobile ittplacebo seed `i'_baseline i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/tablea4check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed `i'_baseline i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/tablea4check.xls", dec(2) append excel ctitle("`i'")
	}

*********************************************************;
*TABLE 7 LOCATION, TIMING AND KNOWLEDGE OF CASH TRANSFER*;
*********************************************************;
set more off
* initialize outreg
		reg resresptransfer ittmobile ittplacebo if time==1, robust cluster(villagecode)
	      	outreg2 using "$replicate/table7.xls", dec(2) replace excel
		reg resresptransfer ittmobile ittcash if time==1, robust cluster(villagecode)
			outreg2 using "$replicate/table7.xls", dec(2) append excel

global timinglocation="receivecashsameday spendone spendmoretwo buytransfer_b buytransfer_marketvill buytransfer_marketout rightmoney rightlengthtransfer"

summ $timinglocation

edit if rightlengthtransfer!=.a & receivetransferconcern==.

//Only in December 2010 round so no time element needed
foreach i in $timinglocation{
	xi: reg `i' ittmobile ittplacebo seed i.commune, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table7.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table7.xls", dec(2) append excel ctitle("`i'")
	}
	
foreach i in $timinglocation{
	tabstat `i' if ittcash==1 & time!=0, stat(mean sd)
	}
	

//Robustness checks (not in tables)

//With comparison group included, same as above

set more off
	reg resresptransfer ittmobile ittplacebo seed if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table7check.xls", dec(2) replace excel
	reg resresptransfer ittmobile ittcash seed if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table7check.xls", dec(2) append excel
	
foreach i in $timinglocation{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table7check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table7check.xls", dec(2) append excel ctitle("`i'")
}

//Without seed fixed effects

foreach i in $timinglocation{
	xi: reg `i' ittmobile ittplacebo i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table7check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table7check.xls", dec(2) append excel ctitle("`i'")
	}

//Control for covariates with baseline differences, such as age, livestock and cowpea
foreach i in $timinglocation{
	xi: reg `i' ittmobile ittplacebo seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table7check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table7check.xls", dec(2) append excel ctitle("`i'")
	}
	
*******************************************;
*TABLE 8 MOBILE PHONE USAGE AND REMITTANCES*
*******************************************;

*PANEL A: MOBILE PHONE USAGE*;
set more off
* initialize outreg
		xi: reg cellphone ittmobile ittplacebo seed i.commune if time!=0, robust cluster(villagecode)
	    outreg2 ittmobile ittplacebo using "$replicate/table8a.xls", replace excel
		xi: reg cellphone ittmobile ittcash seed i.commune if time!=0, robust cluster(villagecode)
		outreg2 ittmobile ittcash using "$replicate/table8a.xls", append excel

global cell="usecell call0 beep0 receivezap0 celltalkrelativeniger0 celltalkrelativeoutside0 celltalktradeniger0 whycell_ceremony0 whycell_priceinfo0 whycell_help0"

//Drop cancall cansms cancredit canzap
//All not conditional on first one
summ $cell
summ $cell if time==1
summ $cell if time==2

set more off
foreach i in $cell{
	xi: reg `i' ittmobile ittplacebo seed time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table8a.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table8a.xls", dec(2) append excel ctitle("`i'")
}

foreach i in $cell{
	tabstat `i' if ittcash==1 & time!=0, stat(mean, sd)
	}

//Do it just for December 2010; not in table
set more off
* initialize outreg
		xi: reg cellphone ittmobile ittplacebo seed i.commune if time!=0, robust cluster(villagecode)
	    outreg2 ittmobile ittplacebo using "$replicate/table8acheck.xls", replace excel
		xi: reg cellphone ittmobile ittcash seed i.commune if time!=0, robust cluster(villagecode)
		outreg2 ittmobile ittcash using "$replicate/table8acheck.xls", append excel
		
foreach i in $cell{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table8acheck.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table8acheck.xls", dec(2) append excel ctitle("`i'")
}

//Do it just for May 2011; not in table. The last variables were only in December 2010

foreach i in usecell call0 beep0 receivezap0 celltalkrelativeniger0 celltalkrelativeoutside0 celltalktradeniger0{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==2, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table8acheck.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time==2, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table8acheck.xls", dec(2) append excel ctitle("`i'")
}

*PANEL B: REMITTANCES*

global remittance="migrate_hh migratehh_percentnet remittance howmuchremit0 nbrremit0 westernunion0 friend0 remitzap0"

summ $remittance if time!=0
summ $remittance if time==1
summ $remittance if time==2

//In general, the "remitttance" variable is less than the how much remit, number of remittances, etc variables.
//The how much remitted is less than the number since sometimes people didn't know, so ".c"

//One outlier of 56 remittances; change to average of 6, does not affect results
//replace nbrremit0=6 if nbrremit==56

set more off

* initialize outreg
		reg remittance ittmobile ittplacebo, robust cluster(villagecode)
	      	outreg2 ittmobile ittplacebo using "$replicate/table8b.xls", dec(2) replace excel
		reg remittance ittmobile ittcash, robust cluster(villagecode)
			outreg2 ittmobile ittcash using "$replicate/table8b.xls", dec(2) append excel
			
foreach i in $remittance{
	xi: reg `i' ittmobile ittplacebo seed time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table8b.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table8b.xls", dec(2) append excel ctitle("`i'")
}

foreach i in $remittance{
	tabstat `i' if ittcash==1 & time!=0, stat(mean, sd)
	}

//Check for if affected by drought; not in table

foreach i in $remittance{
	xi: reg `i' ittmobile ittplacebo seed i.commune if drought0==1 & time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table8bdrought.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if drought0==1 & time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table8bdrought.xls", dec(2) append excel ctitle("`i'")
}

//Robustness checks, same as above

set more off
	reg resresptransfer ittmobile ittplacebo seed if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table8bcheck.xls", dec(2) replace excel
	reg resresptransfer ittmobile ittcash seed if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table8bcheck.xls", dec(2) append excel
	
foreach i in $remittance{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table8bcheck.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table8bcheck.xls", dec(2) append excel ctitle("`i'")
}

//Without seed fixed effects

foreach i in $remittance{
	xi: reg `i' ittmobile ittplacebo i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table8bcheck.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table8bcheck.xls", dec(2) append excel ctitle("`i'")
	}

//Control for covariates with baseline differences, such as age, livestock and cowpea
foreach i in $remittance{
	xi: reg `i' ittmobile ittplacebo seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table8bcheck.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table8bcheck.xls", dec(2) append excel ctitle("`i'")
	}
	
***********************************;
*TABLE A5: INTER-HOUSEHOLD SHARING*;
***********************************;
set more off
global share="sharetransfer sharetfamvill0 sharegood sharegfamvill0"

summ $share

set more off
* initialize outreg
		xi: reg sharetransfer ittmobile ittplacebo i.commune if time!=0, robust cluster(villagecode)
	    outreg2 ittmobile ittplacebo using "$replicate/tablea5.xls", dec(2) replace excel
		xi: reg sharetransfer ittmobile ittcash i.commune if time!=0, robust cluster(villagecode)
		outreg2 ittmobile ittcash using "$replicate/tablea5.xls", dec(2) append excel
			
foreach i in $share{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/tablea5.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/tablea5.xls", dec(2) append excel ctitle("`i'")
	}

foreach i in $share{
	tabstat `i' if ittcash==1, stat(mean, sd)
}
	
*****************************************;
*TABLE 9 INTRA-HOUSEHOLD DECISION-MAKING*;
*****************************************;

**************************************************************;
*PANEL A INVOLVEMENT ON TRANSFER OR TRAVEL TO OBTAIN TRANSFER*;
**************************************************************;
set more off
* initialize outreg
		reg resresptransfer ittmobile ittplacebo if time==1, robust cluster(villagecode)
	      	outreg2 using "$replicate/table9.xls", dec(2) replace excel
		reg resresptransfer ittmobile ittcash if time==1, robust cluster(villagecode)
			outreg2 using "$replicate/table9.xls", dec(2) append excel

global transferdecide="resresptransfer respinvolvetransfer0"

summ $transferdecide

foreach i in $transferdecide{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9.xls", dec(2) append excel ctitle("`i'")
	}

foreach i in $transferdecide{
	tabstat `i' if ittcash==1, stat(mean, sd)
}

//Robustness checks (not included in table)

set more off
	reg resresptransfer ittmobile ittplacebo seed if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9check.xls", dec(2) replace excel
	reg resresptransfer ittmobile ittcash seed if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9check.xls", dec(2) append excel
	
foreach i in $transferdecide{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")
}

//Without seed fixed effects

foreach i in $transferdecide{
	xi: reg `i' ittmobile ittplacebo i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")
	}

//Control for covariates with baseline differences, such as age, livestock and cowpea
foreach i in $transferdecide{
	xi: reg `i' ittmobile ittplacebo seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")
	}
	
*********************************************;
*PANEL B: WOMEN'S INVOLVEMENT IN AGRICULTURE*;
*********************************************;

global decide="visitmarketlastweek sellcerealsresp0"

//Cultivate was only asked for periods 0 and 1, so is not good for period 2 as a prompt

//The sell cereals are for two time periods, the first one is only for one time period

summ $decide
summ $decide if time==1
summ $decide if time==2

//The below is just for time==1, since the visit market one is only available then; the results are similar for the selling cereals if pooling it, but smaller magnitude

	xi: reg visitmarketlastweek ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9.xls", dec(2) append excel ctitle("`i'")
	xi: reg visitmarketlastweek ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9.xls", dec(2) append excel ctitle("`i'")

//The below is for both, then time 1, then time 2
	xi: reg sellcerealsresp0 ittmobile ittplacebo seed time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9.xls", dec(2) append excel ctitle("`i'")
	xi: reg sellcerealsresp0 ittmobile ittcash seed time i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9.xls", dec(2) append excel ctitle("`i'")

	xi: reg sellcerealsresp0 ittmobile ittplacebo seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9.xls", dec(2) append excel ctitle("`i'")
	xi: reg sellcerealsresp0 ittmobile ittcash seed i.commune if time==1, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9.xls", dec(2) append excel ctitle("`i'")

	xi: reg sellcerealsresp0 ittmobile ittplacebo seed i.commune if time==2, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9.xls", dec(2) append excel ctitle("`i'")
	xi: reg sellcerealsresp0 ittmobile ittcash seed i.commune if time==2, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9.xls", dec(2) append excel ctitle("`i'")


tabstat visitmarketlastweek if ittcash==1 & time==1, stat(mean, sd)
tabstat sellcerealsresp0 if ittcash==1 & time!=0, stat(mean, sd)


//Robustness checks for sellrespondent

//Without seed fixed effects

	xi: reg sellcerealsresp0 ittmobile ittplacebo i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")
	xi: reg sellcerealsresp0 ittmobile ittcash i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")


//Control for covariates with baseline differences, such as age, livestock and cowpea; this is significant

	xi: reg sellcerealsresp0 ittmobile ittplacebo seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")
	xi: reg sellcerealsresp0 ittmobile ittcash seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")


****************************;
*PANEL C: CLOTHING EXPENSES*;
****************************;
global clothing="anycloth_womanchild clotheschild0"

edit if clotheschild0==. & anycloth_womanchild!=. & time==2
sort id time

summ $clothing if time==2
//Only collected the data in time==2
summ $clothing if time==1

set more off

//The below is just for time==2 since only data from that period

foreach i in $clothing{
	xi: reg `i' ittmobile ittplacebo seed i.commune if time==2, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed i.commune if time==2, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9.xls", dec(2) append excel ctitle("`i'")
	}

foreach i in $clothing{
	tabstat `i' if ittcash==1 & time==2, stat(mean, sd)
	}

//Robustness checks for clothing

//Without seed fixed effects
foreach i in $clothing{
	xi: reg `i' ittmobile ittplacebo i.commune if time==2, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash i.commune if time==2, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")
	}

//Control for covariates with baseline differences, such as age, livestock and cowpea
foreach i in $clothing{
	xi: reg `i' ittmobile ittplacebo seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time==2, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")
	xi: reg `i' ittmobile ittcash seed hhage_baseline livestock_baseline cowpea_baseline i.commune if time==2, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table9check.xls", dec(2) append excel ctitle("`i'")
	}
	
***********************************;
*TABLE 10 ALTERNATIVE EXPLANATIONS*;
***********************************;
set more off
global infrastructure="market agentzap agentzapnum"
global shock="drought0 illness0"

//The infrastructure data are from May 2011, and from the village-level survey.  Thus, in theory, this should be collapsed, as it is the same observation per village.
//Do shock data first

summ $shock if time==1

		xi: reg drought0 ittmobile ittplacebo seed i.commune if time!=0, robust cluster(villagecode)
	    outreg2 using "$replicate/table10b.xls", dec(2) replace excel
		xi: reg drought0 ittmobile ittcash seed i.commune if time!=0, robust cluster(villagecode)
		outreg2 using "$replicate/table10b.xls", dec(2) append excel

foreach i in $shock{
	xi: reg `i' ittmobile ittplacebo time seed i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittplacebo using "$replicate/table10b.xls", dec(2) append excel
	xi: reg `i' ittmobile ittcash time seed i.commune if time!=0, robust cluster(villagecode)
	outreg2 ittmobile ittcash using "$replicate/table10b.xls", dec(2) append excel
}

foreach i in $shock{
	tabstat `i' if ittcash==1 & time!=0, stat(mean, sd)
	}

summ $infrastructure if time==2

collapse market agentzap agentzapnum ittmobile ittplacebo ittcash seed commune if time==2, by(villagecode)

		xi: reg market ittmobile ittplacebo i.commune, robust
	    outreg2 using "$replicate/table10a.xls", dec(2) replace excel
		xi: reg market ittmobile ittcash i.commune, robust
		outreg2 using "$replicate/table10a.xls", dec(2) append excel

foreach i in $infrastructure{
	xi: reg `i' ittmobile ittplacebo seed i.commune, robust
	outreg2 ittmobile ittplacebo using "$replicate/table10a.xls", dec(2) append excel
	xi: reg `i' ittmobile ittcash seed i.commune, robust
	outreg2 ittmobile ittcash using "$replicate/table10a.xls", dec(2) append excel
}

foreach i in $infrastructure{
	tabstat `i' if ittcash==1, stat(mean, sd)
	}

//Check without commune fixed effects, since these eat up a lot of degrees of freedom - not in the table but as robustness check

foreach i in $infrastructure{
	reg `i' ittmobile ittplacebo seed, robust
	outreg2 ittmobile ittplacebo using "$replicate/table10acheck.xls", dec(2) append excel
	reg `i' ittmobile ittcash seed, robust
	outreg2 ittmobile ittcash using "$replicate/table10acheck.xls", dec(2) append excel
}

clear
	
*****************************************************;
*TABLE A6: NUMBER OF TRADERS AND PRODUCT AVAILABILITY;
*****************************************************;

use "$replicate/zapprices.dta", replace
set more off

reg nbrtraders anycash, robust
	      outreg2 anycash using "$replicate/tablea6.xls", replace excel
		  
//Each regression below tries different specifications to see if they change substantially, using different time trends
foreach i in nbrtraders products{
	areg `i' anycash week_no, abs(marketcode) robust cluster(market)
	outreg2 anycash using "$replicate/tablea6.xls", dec(2) append excel
	areg `i' zap cash week_no, abs(marketcode) robust cluster(market)
	test zap=cash=0
	outreg2 zap cash using "$replicate/tablea6.xls", dec(2) append excel
	areg `i' zap cash week_no monthdum*, abs(marketcode) robust cluster(market)
	test zap=cash=0
	outreg2 zap cash using "$replicate/tablea6.xls", dec(2) append excel
	}

//Some of the specifications on number of products show that markets have more products during a Zap week (as compared to non-Zap weeks or no cash markets), but this is not statistically significant as compared with the cash, which is the point

foreach i in nbrtraders products{
	tabstat `i' if cash==0 & month=="July", stat (mean, sd)
	}

*****************;
*TABLE A7. PRICES*;
*****************;

//First create the different variables

foreach i in mil_tia mil_100 sorghum_tia cowpea_tia cowpea_60 rice_1kg rice_50 oil_liter{
	gen ln`i'=log(`i')
	gen lag`i'=L1.`i'
	gen d_`i'=D1.`i'
	gen dln_`i'=D1.ln`i'
	}

//Now create global variables for different dependent variables: differences, logs, levels, differences in logs
global level="mil_tia mil_100 sorghum_tia cowpea_tia cowpea_60 cowpea_100 rice_1kg rice_50 oil_liter"
global diff="d_mil_tia d_cowpea_tia d_cowpea_60 d_rice_1kg d_sorghum_tia d_rice_50 d_oil_liter"
global log="lnmil_tia lnmil_100 lnsorghum_tia lncowpea_tia lncowpea_60 lnrice_1kg lnrice_50 lnoil_liter"

global difflog="dln_mil_tia dln_mil_100 dln_sorghum_tia dln_cowpea_tia dln_cowpea_60 dln_rice_1kg dln_rice_50 dln_oil_liter"

//Test for serial correlation
foreach i in mil_100 cowpea_60 rice_1kg{
	areg `i' anycash week_no, abs(market) robust cluster(week)
	predict res`i', resid
	twoway (scatter res`i' L1.res`i')
	twoway (scatter res`i' week_no)
	}

set more off

//The basic specification is the below

reg mil_tia anycash, robust
outreg2 anycash using "$replicate/tablea7.xls", replace excel

foreach i in $level{
	tabstat `i' if anycash==0, stat(mean, sd)
	}

set more off
reg mil_tia anycash, robust
outreg2 anycash using "$replicate/tablea7.xls", replace excel
	
//The below is logs, which makes the most sense

set more off
//There are only four months (so four clusters), so we can't use that or the var-cov matrix won't be full rank
reg mil_tia anycash, robust
outreg2 anycash using "$replicate/tablea7.xls", replace excel

foreach i in $log{
	areg `i' anycash week_no monthdum*, a(market) robust cluster(market)
	outreg2 anycash using "$replicate/tablea7.xls", dec(2) append excel
	areg `i' zap cash week_no monthdum*, a(market) robust cluster(market)
	outreg2 zap cash using "$replicate/tablea7.xls", dec(2) append excel
	test zap=cash
	}


//The below are in levels with market fixed effects and clustering at both the market level
foreach i in $level{
	areg `i' anycash week_no monthdum*, a(market) robust cluster(market)
	outreg2 anycash using "$replicate/tablea7level.xls", dec(2) append excel
	areg `i' zap cash week_no monthdum*, a(market) robust cluster(market)
	outreg2 zap cash using "$replicate/tablea7level.xls", dec(2) append excel
	test zap=cash
	}
	
clear
log close
